@@ -132,11 +132,20 @@ def init(command=None, argv=None,
     #   >>> os.system("yes | read any")
     #   >>>
     #
-    import signal
-    signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    try:
+        import signal
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    except ValueError:
+        if signal.getsignal(signal.SIGPIPE) != signal.SIG_DFL:
+            iface.warning("SIGPIPE isn't SIG_DFL. Scriptlets may fail.")
 
     return ctrl
 
+def deinit():
+    iface.object = None
+    sysconf.object = None
+    pkgconf.object = None
+
 def initDistro(ctrl):
     # Run distribution script, if available.
     from smart.const import DISTROFILE
