@@ -74,7 +74,7 @@ class RPMMetaDataPackageInfo(PackageInfo):
 
 class RPMMetaDataLoader(Loader):
 
-    __stateversion__ = Loader.__stateversion__+2
+    __stateversion__ = Loader.__stateversion__+3
  
     def __init__(self, filename, filelistsname, baseurl):
         Loader.__init__(self)
@@ -178,10 +178,12 @@ class RPMMetaDataLoader(Loader):
                                   (elem.get("ver"), elem.get("rel"))
 
                 elif tag == SUMMARY:
-                    info["summary"] = elem.text
+                    if elem.text:
+                        info["summary"] = elem.text
 
                 elif tag == DESCRIPTION:
-                    info["description"] = elem.text
+                    if elem.text:
+                        info["description"] = elem.text
 
                 elif tag == SIZE:
                     info["size"] = int(elem.get("package"))
@@ -196,7 +198,8 @@ class RPMMetaDataLoader(Loader):
                     info["location"] = elem.get("href")
 
                 elif tag == GROUP:
-                    info["group"] = elem.text
+                    if elem.text:
+                        info["group"] = elem.text
 
                 elif tag == FILE:
                     filedict[elem.text] = True
@@ -263,7 +266,8 @@ class RPMMetaDataLoader(Loader):
                              name, '<', versionarch)] = True
 
                     reqargs = [x for x in reqdict
-                               if (RPMProvides, x[1], x[3]) not in prvdict]
+                               if x[2] not in ("=",">=","<=") or
+                                  (RPMProvides, x[1], x[3]) not in prvdict]
                     prvargs = prvdict.keys()
                     cnfargs = cnfdict.keys()
                     upgargs = upgdict.keys()
