@@ -197,7 +197,7 @@ class XMLParser(object):
             self._arch = data
 
     def handleSectionEnd(self, name, attrs, data):
-        self._info["group"] = intern(data)
+        self._info["group"] = data
 
     def handleSummaryEnd(self, name, attrs, data):
         self._info["summary"] = data
@@ -294,7 +294,7 @@ class XMLParser(object):
         parser.StartElementHandler = self.startElement
         parser.EndElementHandler = self.endElement
         parser.CharacterDataHandler = self.charData
-        parser.returns_unicode = True
+        parser.returns_unicode = False
 
         self._lastoffset = 0
         self._mod = 0
