@@ -1,4 +1,5 @@
 #
+# Copyright (c) 2005 Canonical
 # Copyright (c) 2004 Conectiva, Inc.
 #
 # Written by Gustavo Niemeyer <niemeyer@conectiva.com>
@@ -150,7 +151,9 @@ def main(ctrl, opts, reloadchannels=True):
 
         if opts.paths:
             print _("Paths:")
-            for entry in info.getPathList():
+            paths = info.getPathList()
+            paths.sort()
+            for entry in paths:
                 print "", entry
         print
 
