@@ -68,12 +68,24 @@ def parse_options(argv):
                              "when possible"))
     parser.add_option("-y", "--yes", action="store_true",
                       help=_("do not ask for confirmation"))
+    parser.add_option("--dump", action="store_true",
+                      help=_("dump package names and versions to stderr but "
+                             "don't commit operation"))
+    parser.add_option("--dump-noversion", action="store_true",
+                      help=_("dump package names without versions to stderr but "
+                             "don't commit operation"))
+    parser.add_option("--dump-tofile", metavar=_("FILE"),
+                      help=_("dump packages in transaction to a file"))
     opts, args = parser.parse_args(argv)
     opts.args = args
     return opts
 
 def main(ctrl, opts):
 
+    if opts.dump_tofile and not (opts.dump or opts.dump_noversion):
+        raise Error, _("Option 'dump-tofile' must be used with 'dump'"
+                       "or 'dump-noversion'.")
+
     if opts.explain:
         sysconf.set("explain-changesets", True, soft=True)
 
@@ -123,7 +135,7 @@ def main(ctrl, opts):
                     foundany = True
             if not foundany:
                 for obj in results:
-                    if not isinstance(obj, Packages):
+                    if not isinstance(obj, Package):
                         for pkg in obj.packages:
                             if pkg.installed:
                                 foundinstalled = True
@@ -174,6 +186,10 @@ def main(ctrl, opts):
         confirm = not opts.yes
         if opts.urls:
             ctrl.dumpTransactionURLs(trans)
+        elif opts.dump:
+            ctrl.dumpTransactionPackages(trans, "upgrade", noversion=False, file=opts.dump_tofile)
+        elif opts.dump_noversion:
+            ctrl.dumpTransactionPackages(trans, "upgrade", noversion=True, file=opts.dump_tofile)
         elif opts.download:
             ctrl.downloadTransaction(trans, confirm=confirm)
         elif opts.stepped:
