@@ -414,6 +414,31 @@ class Control(object):
         for url in urls:
             print >>output, url
 
+    def dumpTransactionPackages(self, trans, action="install", noversion=False, file=""):
+        print
+        from smart.report import Report
+        report = Report(trans.getChangeSet())
+        report.compute()
+        if action == "install":
+            pkgs = report.installing
+        elif action == "upgrade":
+            pkgs = report.upgrading
+        elif action == "remove":
+            pkgs = report.removed
+        items = pkgs.items()
+        items.sort()
+        pkgs = [key for key, value in items]
+        if file:
+            output = open(file, 'w')
+        else:
+            output = sys.stderr
+        for pkg in pkgs:
+            if noversion:
+                print >>output, pkg.name
+            else:
+                print >>output, pkg
+        if file:output.close()
+
     def downloadURLs(self, urllst, what=None, caching=NEVER, targetdir=None):
         fetcher = self._fetcher
         fetcher.reset()
@@ -460,12 +485,31 @@ class Control(object):
                 break
         return True
 
+    def writeCommitLog(self, changeset):
+        """ writes the operations performed in the current changeset
+            to a log file specified with via the sysconf"commit-log"
+            variable
+        """
+        logfile = sysconf.get("commit-log",None)
+        if logfile == None:
+            return
+        logdir = os.path.join(sysconf.get("data-dir"), "logs/")
+        if not os.path.isdir(logdir):
+            os.makedirs(logdir)
+        log = open(logdir+logfile,"a")
+        for pkg in changeset:
+            log.write("%s %s: %s\n" % (time.ctime(), pkg, changeset[pkg]))
+        log.write("\n")
+
     def commitTransaction(self, trans, caching=OPTIONAL, confirm=True):
         return self.commitChangeSet(trans.getChangeSet(), caching, confirm)
 
     def commitChangeSet(self, changeset, caching=OPTIONAL, confirm=True):
         if confirm and not iface.confirmChangeSet(changeset):
             return False
+            
+        if not confirm:
+            iface.showChangeSet(changeset)
 
         setCloseOnExecAll()
 
@@ -515,6 +559,7 @@ class Control(object):
                         if pkg in cs:
                             pmcs[pkg] = cs[pkg]
                     if sysconf.get("commit", True):
+                        self.writeCommitLog(pmcs)
                         pmclass().commit(pmcs, pkgpaths)
 
                 if sysconf.get("remove-packages", True):
@@ -577,7 +622,7 @@ class Control(object):
             cs = ChangeSet(self._cache, unioncs)
             splitter.include(unioncs, pkg)
             cs = unioncs.difference(cs)
-            self.commitChangeSet(cs)
+            self.commitChangeSet(cs, confirm=confirm)
 
         return True
 
