@@ -20,7 +20,7 @@
 # along with Smart Package Manager; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-from smart.util.strtools import sizeToStr, speedToStr
+from smart.util.strtools import sizeToStr, speedToStr, secondsToStr
 from smart.media import MediaSet, DeviceMedia
 from smart.uncompress import Uncompressor
 from smart.mirror import MirrorSystem
@@ -39,7 +39,7 @@ MAXRETRIES = 30
 SPEEDDELAY = 1
 CANCELDELAY = 2
 MAXACTIVEDOWNLOADS = 10
-SOCKETTIMEOUT = 120
+SOCKETTIMEOUT = 30
 
 class FetcherCancelled(Error): pass
 
@@ -67,6 +67,7 @@ class Fetcher(object):
         self._activedownloadslock = thread.allocate_lock()
         self._maxactivedownloads = 0
         self.time = 0
+        self._eta = 0
 
     def reset(self):
         self._items.clear()
@@ -261,6 +262,7 @@ class Fetcher(object):
                       not item.getInfo("uncomp")):
                     if updatespeed:
                         item.updateSpeed()
+                        item.updateETA()
                     continue
                 localpath = item.getTargetPath()
                 if localpath in uncompchecked:
@@ -339,7 +341,7 @@ class Fetcher(object):
     def validate(self, item, localpath, withreason=False, uncomp=False):
         try:
             if not os.path.isfile(localpath):
-                raise Error, _("File not found")
+                raise Error, _("File not found for validation")
 
             if uncomp:
                 uncompprefix = "uncomp_"
@@ -411,6 +413,7 @@ class FetchItem(object):
         self._current = 0
         self._total = 0
         self._speed = 0
+        self._eta = 0
         self._speedtime = 0
         self._speedcurrent = 0
 
@@ -512,6 +515,7 @@ class FetchItem(object):
                 subdata["current"] = sizeToStr(current)
                 subdata["total"] = sizeToStr(total)
                 subdata["speed"] = speedToStr(self._speed)
+                subdata["eta"] = secondsToStr(self._eta)
                 self._progress.setSub(self._urlobj.original, current, total, 1,
                                       subdata)
                 self._progress.show()
@@ -532,6 +536,13 @@ class FetchItem(object):
                 self._speedcurrent = self._current
                 self.progress(self._current, self._total)
 
+    def updateETA(self):
+        if self._status is RUNNING:
+            if (self._speed > 0) and (self._total > 0):
+                self._eta = (self._total - self._current) / self._speed
+            else:
+                self._eta = None
+
     def setSucceeded(self, targetpath, fetchedsize=0):
         if self._status is not FAILED:
             self._status = SUCCEEDED
@@ -1098,7 +1109,15 @@ class URLLIBHandler(FetcherHandler):
         class Opener(urllib.FancyURLopener):
             user = None
             passwd = None
-            def prompt_user_passwd(self, host, realm):
+            def __init__(self, *args, **kwargs):
+                self.retrycount = 3
+                urllib.FancyURLopener.__init__(self, *args, **kwargs)
+            def http_error_401(self, url, fp, errcode, errmsg, headers, data=None):
+                self.retrycount -= 1
+                if self.retrycount <= 0:
+                    return self.http_error_default(url, fp, errcode, errmsg, headers)
+                return urllib.FancyURLopener.http_error_401(self, url, fp, errcode, errmsg, headers, data)
+            def get_user_passwd(self, host, realm):
                 return self.user, self.passwd
             def http_error_default(self, url, fp, errcode, errmsg, headers):
                 if not fp:
@@ -1617,14 +1636,21 @@ class PyCurlHandler(FetcherHandler):
                         handle.setopt(pycurl.NOPROGRESS, 0)
                         handle.setopt(pycurl.PROGRESSFUNCTION, progress)
                         handle.setopt(pycurl.WRITEDATA, local)
+                        handle.setopt(pycurl.FOLLOWLOCATION, 1)
+                        handle.setopt(pycurl.MAXREDIRS, 5)
 
+                        # check if we have a valid local file and use I-M-S
                         if fetcher.validate(item, localpath):
                             handle.setopt(pycurl.TIMECONDITION,
                                           pycurl.TIMECONDITION_IFMODSINCE)
                             mtime = os.path.getmtime(localpath)
                             if url.scheme == "ftp":
                                 mtime += 1 # libcurl handles ftp mtime wrongly
-                            handle.setopt(pycurl.TIMEVALUE, mtime)
+                            handle.setopt(pycurl.TIMEVALUE, int(mtime))
+                        else:
+                            # reset the I-M-S option 
+                            handle.setopt(pycurl.TIMECONDITION,
+                                          pycurl.TIMECONDITION_NONE)
 
                         self._lock.acquire()
                         multi.add_handle(handle)
